@@ -7,6 +7,7 @@ from sklearn.metrics import mean_absolute_error
 from sklearn.model_selection import KFold, ShuffleSplit
 from multiprocessing.pool import ThreadPool
 from mlni.utils import time_bar
+from joblib import dump
 
 __author__ = "Junhao Wen"
 __copyright__ = "Copyright 2019-2020 The CBICA & SBIA Lab"
@@ -164,7 +165,7 @@ class LinearSVRAlgorithmWithPrecomputedKernel(RegressionAlgorithm):
 
     def evaluate(self, train_index, test_index):
 
-        inner_pool = ThreadPool(self._n_threads)
+        inner_pool = ThreadPool(processes=self._n_threads)
         async_result = {}
         for i in range(self._grid_search_folds):
             async_result[i] = {}
@@ -231,6 +232,8 @@ class LinearSVRAlgorithmWithPrecomputedKernel(RegressionAlgorithm):
         np.savetxt(os.path.join(output_dir, 'dual_coefficients.txt'), classifier.dual_coef_)
         np.savetxt(os.path.join(output_dir, 'support_vectors_indices.txt'), classifier.support_)
         np.savetxt(os.path.join(output_dir, 'intersect.txt'), classifier.intercept_)
+        ## save the svr instance to apply external test data
+        dump(classifier, os.path.join(output_dir, 'svr.joblib'))
 
     def save_weights(self, classifier, x, output_dir):
 
@@ -269,7 +272,7 @@ class RepeatedHoldOut(RegressionValidation):
             self._cv = list(splits.split(np.zeros(len(y)), y))
         else:
             self._cv = splits_indices
-        async_pool = ThreadPool(n_threads)
+        async_pool = ThreadPool(processes=n_threads)
         async_result = {}
 
         for i in range(self._n_iterations):
@@ -458,7 +461,7 @@ class KFoldCV(RegressionValidation):
         else:
             self._cv = splits_indices
 
-        async_pool = ThreadPool(n_threads)
+        async_pool = ThreadPool(processes=n_threads)
         async_result = {}
 
         for i in range(n_folds):
